#
# spec file for package mgr-push
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2008-2018 Red Hat, Inc.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Old name and version+1 before renaming to mgr-push
%define oldname rhnpush
%define oldversion 5.5.114
%{!?pylint_check: %global pylint_check 0}
%global __python /usr/bin/python2

%if 0%{?fedora} || 0%{?suse_version} > 1320 || 0%{?rhel} >= 8
%global build_py3   1
%global default_py3 1
%endif

%if !( 0%{?rhel} >= 8 )
%global build_py2   1
%endif

%define pythonX %{?default_py3: python3}%{!?default_py3: python2}

Name:           mgr-push
Summary:        Package uploader for the Spacewalk
License:        GPL-2.0-only
Group:          Applications/System
Url:            https://github.com/uyuni-project/uyuni
Version:        4.2.2
Provides:       %{oldname} = %{oldversion}
Obsoletes:      %{oldname} < %{oldversion}
Release:    1.9.1
Source0: mgr-push-git-0.5286df2.tar.gz
Source1:        %{name}-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?fedora} || 0%{?rhel} || 0%{?suse_version} >= 1210
BuildArch:      noarch
%endif
Requires:       %{pythonX}-%{name} = %{version}-%{release}
BuildRequires:  docbook-utils
BuildRequires:  gettext
%if 0%{?pylint_check}
%if 0%{?build_py2}
BuildRequires:  spacewalk-python2-pylint
%endif
%if 0%{?build_py3}
BuildRequires:  spacewalk-python3-pylint
%endif
%endif

%description
rhnpush uploads package headers to the Spacewalk
servers into specified channels and allows for several other channel
management operations relevant to controlling what packages are available
per channel.

%if 0%{?build_py2}
%package -n python2-%{name}
Summary:        Package uploader for the Spacewalk or Red Hat Satellite Server
Group:          Applications/System
Provides:       python2-%{oldname} = %{oldversion}
Obsoletes:      python2-%{oldname} < %{oldversion}
Requires:       %{name} = %{version}-%{release}
%if 0%{?fedora} >= 28
Requires:       python2-rpm
BuildRequires:  python2-devel
%else
Requires:       rpm-python
BuildRequires:  python-devel
%endif
Requires:       python2-rhn-client-tools
Requires:       rhnlib >= 2.8.3
Requires:       python2-uyuni-common-libs
BuildRequires:  python2-rhn-client-tools
BuildRequires:  python2-uyuni-common-libs

%description -n python2-%{name}
Python 2 specific files for rhnpush.
%endif

%if 0%{?build_py3}
%package -n python3-%{name}
Summary:        Package uploader for the Spacewalk or Red Hat Satellite Server
Group:          Applications/System
Provides:       python3-%{oldname} = %{oldversion}
Obsoletes:      python3-%{oldname} < %{oldversion}
Requires:       %{name} = %{version}-%{release}
%if 0%{?suse_version}
Requires:       python3-rpm
%else
Requires:       rpm-python3
%endif
Requires:       python3-rhn-client-tools
Requires:       python3-rhnlib >= 2.8.3
Requires:       python3-uyuni-common-libs
BuildRequires:  python3-devel
BuildRequires:  python3-rhn-client-tools
BuildRequires:  python3-rpm-macros
BuildRequires:  python3-uyuni-common-libs

%description -n python3-%{name}
Python 3 specific files for rhnpush.
%endif

%prep
%setup -q -n mgr-push-git-0.5286df2

%build
make -f Makefile.rhnpush all

%install
install -d $RPM_BUILD_ROOT/%{python_sitelib}
%if 0%{?build_py2}
make -f Makefile.rhnpush install PREFIX=$RPM_BUILD_ROOT ROOT=%{python_sitelib} \
    MANDIR=%{_mandir} PYTHON_VERSION=%{python_version}
%endif

%if 0%{?build_py3}
sed -i 's|#!/usr/bin/python|#!/usr/bin/python3|' rhnpush
install -d $RPM_BUILD_ROOT/%{python3_sitelib}
make -f Makefile.rhnpush install PREFIX=$RPM_BUILD_ROOT ROOT=%{python3_sitelib} \
    MANDIR=%{_mandir} PYTHON_VERSION=%{python3_version}
%endif

%define default_suffix %{?default_py3:-%{python3_version}}%{!?default_py3:-%{python_version}}
ln -s rhnpush%{default_suffix} $RPM_BUILD_ROOT%{_bindir}/rhnpush
%if 0%{?suse_version}
ln -s rhnpush $RPM_BUILD_ROOT/%{_bindir}/mgrpush
%endif

%check
%if 0%{?pylint_check}
# check coding style
%if 0%{?build_py2}
export PYTHONPATH=$RPM_BUILD_ROOT%{python_sitelib}
spacewalk-python2-pylint $RPM_BUILD_ROOT%{_bindir} $RPM_BUILD_ROOT%{python_sitelib}
%endif
%if 0%{?build_py3}
export PYTHONPATH=$RPM_BUILD_ROOT%{python3_sitelib}
spacewalk-python3-pylint $RPM_BUILD_ROOT%{_bindir} $RPM_BUILD_ROOT%{python3_sitelib}
%endif
%endif

%files
%defattr(-,root,root)
%{_bindir}/rhnpush
%{_bindir}/rpm2mpm
%dir %{_sysconfdir}/sysconfig/rhn
%if 0%{?suse_version}
%{_bindir}/mgrpush
%endif
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/sysconfig/rhn/rhnpushrc
%{_mandir}/man8/rhnpush.8*
%doc COPYING

%if 0%{?build_py2}
%files -n python2-%{name}
%defattr(-,root,root)
%attr(755,root,root) %{_bindir}/rhnpush-%{python_version}
%{python_sitelib}/rhnpush/
%endif

%if 0%{?build_py3}
%files -n python3-%{name}
%defattr(-,root,root)
%attr(755,root,root) %{_bindir}/rhnpush-%{python3_version}
%{python3_sitelib}/rhnpush/
%endif

%changelog
* Thu Dec  3 2020 jgonzalez@suse.com
- version 4.2.2-1
- defined __python for python2.
- Excluded RHEL8 for Python 2 build.
* Fri Sep 18 2020 jgonzalez@suse.com
- version 4.2.1-1
- Update package version to 4.2.0
* Wed Nov 27 2019 jgonzalez@suse.com
- version 4.1.1-1
- replace spacewalk-usix and spacewalk-backend-libs with uyuni-common-libs
- Bump version to 4.1.0 (bsc#1154940)
* Wed May 15 2019 jgonzalez@suse.com
- version 4.0.6-1
- Obsolete newer versions of rhnpush
* Wed May 15 2019 jgonzalez@suse.com
- version 4.0.5-1
- SPEC cleanup
- Fix wrong bugzilla entry at changelog
* Mon Apr 22 2019 jgonzalez@suse.com
- version 4.0.4-1
- add makefile and configuration for pylint
* Wed Jan 16 2019 jgonzalez@suse.com
- version 4.0.3-1
- Fix dependencies to spacewalk-backend-libs
* Fri Oct 26 2018 jgonzalez@suse.com
- version 4.0.2-1
- Add Uyuni URL to package
* Fri Aug 10 2018 jgonzalez@suse.com
- version 4.0.1-1
- Bump version to 4.0.0 (bsc#1104034)
- Rename package to mgr-push to allow version 4.0.0 (bsc#1104034)
- Fix copyright for the package specfile (bsc#1103696)
* Mon Apr 23 2018 jgonzalez@suse.com
- version 5.5.113.2-1
- Sync with upstream (bsc#1083294)
- rhnpush is needed on python2 due to spacewalk-proxy
* Mon Mar 26 2018 jgonzalez@suse.com
- version 5.5.113.1-1
- Sync with upstream (bsc#1083294)
- Build python2 on SUSE
* Mon Mar  5 2018 jgonzalez@suse.com
- version 5.5.111.2-1
- remove empty clean section from spec (bsc#1083294)
* Fri Feb 23 2018 jgonzalez@suse.com
- version 5.5.111.1-1
- Sync with upstream
* Thu Oct 26 2017 mc@suse.de
- version 5.5.108.1-1
- move rhnpush files into proper python2/python3 subpackages
* Wed Aug  9 2017 fkobzik@suse.de
- version 5.5.104.3-1
- disable pylint check during build also for RHEL7
* Mon May 29 2017 mc@suse.de
- version 5.5.104.2-1
- fixed pylint warnings disabled python3 pylint on Fedora 26+ for now
- removed outdated solaris2mpm script
* Fri Mar 31 2017 mc@suse.de
- version 5.5.104.1-1
- Pylint fixes in rhnpush
* Tue Mar  7 2017 mc@suse.de
- version 5.5.102.1-1
- Updated links to github in spec files
- require spacewalk-usix indead of spacewalk-backend-usix
* Wed Jan 11 2017 michele.bologna@suse.com
- version 5.5.101.1-1
- Version 5.5.101-1
* Wed Apr  6 2016 mc@suse.de
- version 5.5.91.2-1
- don't count on having newest rhn-client-tools
* Sat Jan 16 2016 mc@suse.de
- version 5.5.91.1-1
- alow to use existing rpcServer when creating RhnServer
* Mon Nov 30 2015 mc@suse.de
- version 5.5.90.1-1
- rhn-satellite-activate: manual references removed
* Wed Oct  7 2015 mc@suse.de
- version 5.5.89.1-1
- Wire in timeout for rhnpush
* Mon Jun 22 2015 jrenner@suse.de
- version 5.5.71.8-1
- fix --ca-chain option for rhnpush (bsc#931503, bsc#895869)
* Tue Feb  3 2015 mc@suse.de
- version 5.5.71.7-1
- Getting rid of Tabs and trailing spaces
* Thu Dec 18 2014 mc@suse.de
- version 5.5.71.6-1
- rhnpush: fix pylint checks and code quality
* Wed Sep  3 2014 ro@suse.de
- sanitize release line in specfile
* Fri Jun 13 2014 jrenner@suse.de
- version 5.5.71.5-1
- Add default path structure to proxy lookaside that avoids collisions
- Make rhnpush backwards-compatible with old spacewalk-proxy
* Thu Apr 10 2014 mc@suse.de
- version 5.5.71.4-1
* Thu Apr 10 2014 mc@suse.de
- fix release in specfile for SLE12 (bnc#872970)
* Thu Mar 27 2014 fcastelli@suse.com
- version 5.5.71.3-1
- correcting exception type
* Thu Feb 13 2014 mc@suse.de
- version 5.5.71.2-1
- use SUSE package name in requires
- pylint check only on SLE11
* Tue Dec 10 2013 mc@suse.de
- version 5.5.71.1-1
- switch to 2.1
* Thu Aug  2 2012 mc@suse.de
- version 5.5.42.7-1
- code cleanup
- fixed man page
- removed dead --no-cache option
- fixed --no-session-caching option
* Mon Jul 16 2012 ug@suse.de
- version 5.5.42.6-1
- solaris2mpm on RHEL5 is not supported
- solaris2mpm needs zipfile with ZIP64 extension
- remove trailing '/' from from archive dir
- reuse UploadError from uploadLib
- simplified authentication code
* Mon Jun 25 2012 mc@suse.de
- version 5.5.42.5-1
- removed commented out code and obsoleted comments
* Thu Jun 21 2012 jrenner@suse.de
- version 5.5.42.4-1
- add COPYING file (bnc#764854)
* Thu May 31 2012 mc@suse.de
- version 5.5.42.3-1
- Use the correct a_pkg variable.
* Fri Apr 27 2012 mc@suse.de
- version 5.5.42.2-1
- removed unused get_header_struct_size()
- removed unused function get_header_byte_range()
* Wed Mar 21 2012 mc@suse.de
- version 5.5.42.1-1
- Bumping package version
* Tue Feb 22 2011 mantel@suse.de
- add missing "import string" (bnc#672643)
* Thu Feb 17 2011 mantel@suse.de
- fix build: create symlink only after binary has been installed
* Thu Feb 17 2011 mantel@suse.de
- rename "Red Hat Network" to "SUSE Manager" for SUSE (bnc#672643)
- add mgrpush symlink (bnc#672643)
* Tue Feb  1 2011 mc@suse.de
- fix build for RH4
* Tue Jan 11 2011 mc@suse.de
- tag strings which needs changes
- fix Requires line in spec
* Wed Sep 15 2010 mantel@suse.de
- fix post-build-checks
* Tue Sep 14 2010 mantel@suse.de
- Initial release of rhnpush
